@@ -1,6 +1,8 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package csgo
 
 import (
+	_ "embed"
 	"encoding/json"
 	"errors"
 	"strconv"
@@ -14,6 +16,10 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
+// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
+//go:embed sample.conf
+var sampleConfig string
+
 type statsData struct {
 	CPU           float64 `json:"cpu"`
 	NetIn         float64 `json:"net_in"`
@@ -31,21 +37,6 @@ type CSGO struct {
 	Servers [][]string `toml:"servers"`
 }
 
-func (*CSGO) Description() string {
-	return "Fetch metrics from a CSGO SRCDS"
-}
-
-var sampleConfig = `
-  ## Specify servers using the following format:
-  ##    servers = [
-  ##      ["ip1:port1", "rcon_password1"],
-  ##      ["ip2:port2", "rcon_password2"],
-  ##    ]
-  #
-  ## If no servers are specified, no data will be collected
-  servers = []
-`
-
 func (*CSGO) SampleConfig() string {
 	return sampleConfig
 }
