@@ -1,7 +1,9 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package influxdb
 
 import (
 	"bytes"
+	_ "embed"
 	"encoding/json"
 	"errors"
 	"io"
@@ -16,6 +18,10 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
+// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
+//go:embed sample.conf
+var sampleConfig string
+
 const (
 	maxErrorResponseBodyLength = 1024
 )
@@ -43,36 +49,8 @@ type InfluxDB struct {
 	client *http.Client
 }
 
-func (*InfluxDB) Description() string {
-	return "Read InfluxDB-formatted JSON metrics from one or more HTTP endpoints"
-}
-
 func (*InfluxDB) SampleConfig() string {
-	return `
-  ## Works with InfluxDB debug endpoints out of the box,
-  ## but other services can use this format too.
-  ## See the influxdb plugin's README for more details.
-
-  ## Multiple URLs from which to read InfluxDB-formatted JSON
-  ## Default is "http://localhost:8086/debug/vars".
-  urls = [
-    "http://localhost:8086/debug/vars"
-  ]
-
-  ## Username and password to send using HTTP Basic Authentication.
-  # username = ""
-  # password = ""
-
-  ## Optional TLS Config
-  # tls_ca = "/etc/telegraf/ca.pem"
-  # tls_cert = "/etc/telegraf/cert.pem"
-  # tls_key = "/etc/telegraf/key.pem"
-  ## Use TLS but skip chain & host verification
-  # insecure_skip_verify = false
-
-  ## http request & header timeout
-  timeout = "5s"
-`
+	return sampleConfig
 }
 
 func (i *InfluxDB) Gather(acc telegraf.Accumulator) error {
