@@ -1,18 +1,22 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package linux_sysctl_fs
 
 import (
 	"bytes"
+	_ "embed"
 	"errors"
-	"io/ioutil"
 	"os"
-	"strconv"
-
 	"path"
+	"strconv"
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
+// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
+//go:embed sample.conf
+var sampleConfig string
+
 // https://www.kernel.org/doc/Documentation/sysctl/fs.txt
 type SysctlFS struct {
 	path string
@@ -21,15 +25,8 @@ type SysctlFS struct {
 var sysctlFSDescription = `Provides Linux sysctl fs metrics`
 var sysctlFSSampleConfig = ``
 
-func (sfs SysctlFS) Description() string {
-	return sysctlFSDescription
-}
-func (sfs SysctlFS) SampleConfig() string {
-	return sysctlFSSampleConfig
-}
-
 func (sfs *SysctlFS) gatherList(file string, fields map[string]interface{}, fieldNames ...string) error {
-	bs, err := ioutil.ReadFile(sfs.path + "/" + file)
+	bs, err := os.ReadFile(sfs.path + "/" + file)
 	if err != nil {
 		// Ignore non-existing entries
 		if errors.Is(err, os.ErrNotExist) {
@@ -58,7 +55,7 @@ func (sfs *SysctlFS) gatherList(file string, fields map[string]interface{}, fiel
 }
 
 func (sfs *SysctlFS) gatherOne(name string, fields map[string]interface{}) error {
-	bs, err := ioutil.ReadFile(sfs.path + "/" + name)
+	bs, err := os.ReadFile(sfs.path + "/" + name)
 	if err != nil {
 		// Ignore non-existing entries
 		if errors.Is(err, os.ErrNotExist) {
@@ -76,6 +73,10 @@ func (sfs *SysctlFS) gatherOne(name string, fields map[string]interface{}) error
 	return nil
 }
 
+func (*SysctlFS) SampleConfig() string {
+	return sampleConfig
+}
+
 func (sfs *SysctlFS) Gather(acc telegraf.Accumulator) error {
 	fields := map[string]interface{}{}
 
