@@ -1,21 +1,29 @@
+//go:generate ../../../tools/readme_config_includer/generator
+//go:build !freebsd || (freebsd && cgo)
 // +build !freebsd freebsd,cgo
 
 package nats
 
 import (
+	_ "embed"
 	"encoding/json"
-	"io/ioutil"
+	"io"
 	"net/http"
 	"net/url"
 	"path"
 	"time"
 
+	gnatsd "github.com/nats-io/nats-server/v2/server"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/plugins/inputs"
-	gnatsd "github.com/nats-io/nats-server/v2/server"
 )
 
+// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
+//go:embed sample.conf
+var sampleConfig string
+
 type Nats struct {
 	Server          string
 	ResponseTimeout config.Duration
@@ -23,39 +31,27 @@ type Nats struct {
 	client *http.Client
 }
 
-var sampleConfig = `
-  ## The address of the monitoring endpoint of the NATS server
-  server = "http://localhost:8222"
-
-  ## Maximum time to receive response
-  # response_timeout = "5s"
-`
-
-func (n *Nats) SampleConfig() string {
+func (*Nats) SampleConfig() string {
 	return sampleConfig
 }
 
-func (n *Nats) Description() string {
-	return "Provides metrics about the state of a NATS server"
-}
-
 func (n *Nats) Gather(acc telegraf.Accumulator) error {
-	url, err := url.Parse(n.Server)
+	address, err := url.Parse(n.Server)
 	if err != nil {
 		return err
 	}
-	url.Path = path.Join(url.Path, "varz")
+	address.Path = path.Join(address.Path, "varz")
 
 	if n.client == nil {
 		n.client = n.createHTTPClient()
 	}
-	resp, err := n.client.Get(url.String())
+	resp, err := n.client.Get(address.String())
 	if err != nil {
 		return err
 	}
 	defer resp.Body.Close()
 
-	bytes, err := ioutil.ReadAll(resp.Body)
+	bytes, err := io.ReadAll(resp.Body)
 	if err != nil {
 		return err
 	}
