@@ -1,16 +1,23 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package nsq_consumer
 
 import (
 	"context"
+	_ "embed"
 	"fmt"
 	"sync"
 
+	nsq "github.com/nsqio/go-nsq"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/plugins/inputs"
 	"github.com/influxdata/telegraf/plugins/parsers"
-	nsq "github.com/nsqio/go-nsq"
 )
 
+// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
+//go:embed sample.conf
+var sampleConfig string
+
 const (
 	defaultMaxUndeliveredMessages = 1000
 )
@@ -49,48 +56,15 @@ type NSQConsumer struct {
 	cancel   context.CancelFunc
 }
 
-var sampleConfig = `
-  ## An array representing the NSQD TCP HTTP Endpoints
-  nsqd = ["localhost:4150"]
-
-  ## An array representing the NSQLookupd HTTP Endpoints
-  nsqlookupd = ["localhost:4161"]
-  topic = "telegraf"
-  channel = "consumer"
-  max_in_flight = 100
-
-  ## Maximum messages to read from the broker that have not been written by an
-  ## output.  For best throughput set based on the number of metrics within
-  ## each message and the size of the output's metric_batch_size.
-  ##
-  ## For example, if each message from the queue contains 10 metrics and the
-  ## output metric_batch_size is 1000, setting this to 100 will ensure that a
-  ## full batch is collected and the write is triggered immediately without
-  ## waiting until the next flush_interval.
-  # max_undelivered_messages = 1000
-
-  ## Data format to consume.
-  ## Each data format has its own unique set of configuration options, read
-  ## more about them here:
-  ## https://github.com/influxdata/telegraf/blob/master/docs/DATA_FORMATS_INPUT.md
-  data_format = "influx"
-`
+func (*NSQConsumer) SampleConfig() string {
+	return sampleConfig
+}
 
 // SetParser takes the data_format from the config and finds the right parser for that format
 func (n *NSQConsumer) SetParser(parser parsers.Parser) {
 	n.parser = parser
 }
 
-// SampleConfig returns config values for generating a sample configuration file
-func (n *NSQConsumer) SampleConfig() string {
-	return sampleConfig
-}
-
-// Description prints description string
-func (n *NSQConsumer) Description() string {
-	return "Read NSQ topic for metrics."
-}
-
 // Start pulls data from nsq
 func (n *NSQConsumer) Start(ac telegraf.Accumulator) error {
 	acc := ac.WithTracking(n.MaxUndeliveredMessages)
