@@ -1,3 +1,4 @@
+//go:generate ../../../tools/readme_config_includer/generator
 //go:build !windows
 // +build !windows
 
@@ -6,6 +7,7 @@
 package postfix
 
 import (
+	_ "embed"
 	"fmt"
 	"os"
 	"os/exec"
@@ -17,13 +19,9 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
-const sampleConfig = `
-  ## Postfix queue directory. If not provided, telegraf will try to use
-  ## 'postconf -h queue_directory' to determine it.
-  # queue_directory = "/var/spool/postfix"
-`
-
-const description = "Measure postfix queue statistics"
+// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
+//go:embed sample.conf
+var sampleConfig string
 
 func getQueueDirectory() (string, error) {
 	qd, err := exec.Command("postconf", "-h", "queue_directory").Output()
@@ -33,9 +31,10 @@ func getQueueDirectory() (string, error) {
 	return strings.TrimSpace(string(qd)), nil
 }
 
-func qScan(path string, acc telegraf.Accumulator) (int64, int64, int64, error) {
+func qScan(path string, acc telegraf.Accumulator) (map[string]interface{}, error) {
 	var length, size int64
 	var oldest time.Time
+
 	err := filepath.Walk(path, func(_ string, finfo os.FileInfo, err error) error {
 		if err != nil {
 			acc.AddError(fmt.Errorf("error scanning %s: %s", path, err))
@@ -57,9 +56,11 @@ func qScan(path string, acc telegraf.Accumulator) (int64, int64, int64, error) {
 		}
 		return nil
 	})
+
 	if err != nil {
-		return 0, 0, 0, err
+		return nil, err
 	}
+
 	var age int64
 	if !oldest.IsZero() {
 		age = int64(time.Since(oldest) / time.Second)
@@ -67,13 +68,23 @@ func qScan(path string, acc telegraf.Accumulator) (int64, int64, int64, error) {
 		// system doesn't support ctime
 		age = -1
 	}
-	return length, size, age, nil
+
+	fields := map[string]interface{}{"length": length, "size": size}
+	if age != -1 {
+		fields["age"] = age
+	}
+
+	return fields, nil
 }
 
 type Postfix struct {
 	QueueDirectory string
 }
 
+func (*Postfix) SampleConfig() string {
+	return sampleConfig
+}
+
 func (p *Postfix) Gather(acc telegraf.Accumulator) error {
 	if p.QueueDirectory == "" {
 		var err error
@@ -84,29 +95,18 @@ func (p *Postfix) Gather(acc telegraf.Accumulator) error {
 	}
 
 	for _, q := range []string{"active", "hold", "incoming", "maildrop", "deferred"} {
-		length, size, age, err := qScan(filepath.Join(p.QueueDirectory, q), acc)
+		fields, err := qScan(filepath.Join(p.QueueDirectory, q), acc)
 		if err != nil {
 			acc.AddError(fmt.Errorf("error scanning queue %s: %s", q, err))
 			continue
 		}
-		fields := map[string]interface{}{"length": length, "size": size}
-		if age != -1 {
-			fields["age"] = age
-		}
+
 		acc.AddFields("postfix_queue", fields, map[string]string{"queue": q})
 	}
 
 	return nil
 }
 
-func (p *Postfix) SampleConfig() string {
-	return sampleConfig
-}
-
-func (p *Postfix) Description() string {
-	return description
-}
-
 func init() {
 	inputs.Add("postfix", func() telegraf.Input {
 		return &Postfix{
