@@ -10,11 +10,11 @@ import (
 	"testing"
 	"time"
 
-	"github.com/influxdata/telegraf/testutil"
-	"github.com/shirou/gopsutil/cpu"
-	"github.com/shirou/gopsutil/process"
-	"github.com/stretchr/testify/assert"
+	"github.com/shirou/gopsutil/v3/cpu"
+	"github.com/shirou/gopsutil/v3/process"
 	"github.com/stretchr/testify/require"
+
+	"github.com/influxdata/telegraf/testutil"
 )
 
 func init() {
@@ -51,11 +51,13 @@ MainPID=11408
 ControlPID=0
 ExecMainPID=11408
 `)
+		//nolint:revive // error code is important for this "test"
 		os.Exit(0)
 	}
 
 	//nolint:errcheck,revive
 	fmt.Printf("command not found\n")
+	//nolint:revive // error code is important for this "test"
 	os.Exit(1)
 }
 
@@ -208,7 +210,7 @@ func TestGather_ProcessName(t *testing.T) {
 	}
 	require.NoError(t, acc.GatherError(p.Gather))
 
-	assert.Equal(t, "custom_name", acc.TagValue("procstat", "process_name"))
+	require.Equal(t, "custom_name", acc.TagValue("procstat", "process_name"))
 }
 
 func TestGather_NoProcessNameUsesReal(t *testing.T) {
@@ -222,7 +224,7 @@ func TestGather_NoProcessNameUsesReal(t *testing.T) {
 	}
 	require.NoError(t, acc.GatherError(p.Gather))
 
-	assert.True(t, acc.HasTag("procstat", "process_name"))
+	require.True(t, acc.HasTag("procstat", "process_name"))
 }
 
 func TestGather_NoPidTag(t *testing.T) {
@@ -234,8 +236,8 @@ func TestGather_NoPidTag(t *testing.T) {
 		createProcess:   newTestProc,
 	}
 	require.NoError(t, acc.GatherError(p.Gather))
-	assert.True(t, acc.HasInt32Field("procstat", "pid"))
-	assert.False(t, acc.HasTag("procstat", "pid"))
+	require.True(t, acc.HasInt32Field("procstat", "pid"))
+	require.False(t, acc.HasTag("procstat", "pid"))
 }
 
 func TestGather_PidTag(t *testing.T) {
@@ -248,8 +250,8 @@ func TestGather_PidTag(t *testing.T) {
 		createProcess:   newTestProc,
 	}
 	require.NoError(t, acc.GatherError(p.Gather))
-	assert.Equal(t, "42", acc.TagValue("procstat", "pid"))
-	assert.False(t, acc.HasInt32Field("procstat", "pid"))
+	require.Equal(t, "42", acc.TagValue("procstat", "pid"))
+	require.False(t, acc.HasInt32Field("procstat", "pid"))
 }
 
 func TestGather_Prefix(t *testing.T) {
@@ -262,7 +264,7 @@ func TestGather_Prefix(t *testing.T) {
 		createProcess:   newTestProc,
 	}
 	require.NoError(t, acc.GatherError(p.Gather))
-	assert.True(t, acc.HasInt32Field("procstat", "custom_prefix_num_fds"))
+	require.True(t, acc.HasInt32Field("procstat", "custom_prefix_num_fds"))
 }
 
 func TestGather_Exe(t *testing.T) {
@@ -275,7 +277,7 @@ func TestGather_Exe(t *testing.T) {
 	}
 	require.NoError(t, acc.GatherError(p.Gather))
 
-	assert.Equal(t, exe, acc.TagValue("procstat", "exe"))
+	require.Equal(t, exe, acc.TagValue("procstat", "exe"))
 }
 
 func TestGather_User(t *testing.T) {
@@ -289,7 +291,7 @@ func TestGather_User(t *testing.T) {
 	}
 	require.NoError(t, acc.GatherError(p.Gather))
 
-	assert.Equal(t, user, acc.TagValue("procstat", "user"))
+	require.Equal(t, user, acc.TagValue("procstat", "user"))
 }
 
 func TestGather_Pattern(t *testing.T) {
@@ -303,7 +305,7 @@ func TestGather_Pattern(t *testing.T) {
 	}
 	require.NoError(t, acc.GatherError(p.Gather))
 
-	assert.Equal(t, pattern, acc.TagValue("procstat", "pattern"))
+	require.Equal(t, pattern, acc.TagValue("procstat", "pattern"))
 }
 
 func TestGather_MissingPidMethod(t *testing.T) {
@@ -327,7 +329,7 @@ func TestGather_PidFile(t *testing.T) {
 	}
 	require.NoError(t, acc.GatherError(p.Gather))
 
-	assert.Equal(t, pidfile, acc.TagValue("procstat", "pidfile"))
+	require.Equal(t, pidfile, acc.TagValue("procstat", "pidfile"))
 }
 
 func TestGather_PercentFirstPass(t *testing.T) {
@@ -342,8 +344,8 @@ func TestGather_PercentFirstPass(t *testing.T) {
 	}
 	require.NoError(t, acc.GatherError(p.Gather))
 
-	assert.True(t, acc.HasFloatField("procstat", "cpu_time_user"))
-	assert.False(t, acc.HasFloatField("procstat", "cpu_usage"))
+	require.True(t, acc.HasFloatField("procstat", "cpu_time_user"))
+	require.False(t, acc.HasFloatField("procstat", "cpu_usage"))
 }
 
 func TestGather_PercentSecondPass(t *testing.T) {
@@ -359,8 +361,8 @@ func TestGather_PercentSecondPass(t *testing.T) {
 	require.NoError(t, acc.GatherError(p.Gather))
 	require.NoError(t, acc.GatherError(p.Gather))
 
-	assert.True(t, acc.HasFloatField("procstat", "cpu_time_user"))
-	assert.True(t, acc.HasFloatField("procstat", "cpu_usage"))
+	require.True(t, acc.HasFloatField("procstat", "cpu_time_user"))
+	require.True(t, acc.HasFloatField("procstat", "cpu_usage"))
 }
 
 func TestGather_systemdUnitPIDs(t *testing.T) {
@@ -374,8 +376,8 @@ func TestGather_systemdUnitPIDs(t *testing.T) {
 		tags := pidsTag.Tags
 		err := pidsTag.Err
 		require.NoError(t, err)
-		assert.Equal(t, []PID{11408}, pids)
-		assert.Equal(t, "TestGather_systemdUnitPIDs", tags["systemd_unit"])
+		require.Equal(t, []PID{11408}, pids)
+		require.Equal(t, "TestGather_systemdUnitPIDs", tags["systemd_unit"])
 	}
 }
 
@@ -384,10 +386,8 @@ func TestGather_cgroupPIDs(t *testing.T) {
 	if runtime.GOOS == "windows" {
 		t.Skip("no cgroups in windows")
 	}
-	td, err := os.MkdirTemp("", "")
-	require.NoError(t, err)
-	defer os.RemoveAll(td)
-	err = os.WriteFile(filepath.Join(td, "cgroup.procs"), []byte("1234\n5678\n"), 0644)
+	td := t.TempDir()
+	err := os.WriteFile(filepath.Join(td, "cgroup.procs"), []byte("1234\n5678\n"), 0644)
 	require.NoError(t, err)
 
 	p := Procstat{
@@ -400,8 +400,8 @@ func TestGather_cgroupPIDs(t *testing.T) {
 		tags := pidsTag.Tags
 		err := pidsTag.Err
 		require.NoError(t, err)
-		assert.Equal(t, []PID{1234, 5678}, pids)
-		assert.Equal(t, td, tags["cgroup"])
+		require.Equal(t, []PID{1234, 5678}, pids)
+		require.Equal(t, td, tags["cgroup"])
 	}
 }
 
