@@ -1,9 +1,16 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package zfs
 
 import (
+	_ "embed"
+
 	"github.com/influxdata/telegraf"
 )
 
+// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
+//go:embed sample.conf
+var sampleConfig string
+
 type Sysctl func(metric string) ([]string, error)
 type Zpool func() ([]string, error)
 type Zdataset func(properties []string) ([]string, error)
@@ -19,27 +26,6 @@ type Zfs struct {
 	Log            telegraf.Logger `toml:"-"`
 }
 
-var sampleConfig = `
-  ## ZFS kstat path. Ignored on FreeBSD
-  ## If not specified, then default is:
-  # kstatPath = "/proc/spl/kstat/zfs"
-
-  ## By default, telegraf gather all zfs stats
-  ## If not specified, then default is:
-  # kstatMetrics = ["arcstats", "zfetchstats", "vdev_cache_stats"]
-  ## For Linux, the default is:
-  # kstatMetrics = ["abdstats", "arcstats", "dnodestats", "dbufcachestats",
-  #   "dmu_tx", "fm", "vdev_mirror_stats", "zfetchstats", "zil"]
-  ## By default, don't gather zpool stats
-  # poolMetrics = false
-  ## By default, don't gather zdataset stats
-  # datasetMetrics = false
-`
-
-func (z *Zfs) SampleConfig() string {
+func (*Zfs) SampleConfig() string {
 	return sampleConfig
 }
-
-func (z *Zfs) Description() string {
-	return "Read metrics of ZFS from arcstats, zfetchstats, vdev_cache_stats, pools and datasets"
-}
