@@ -11,11 +11,11 @@ import (
 	"testing"
 	"time"
 
-	"github.com/influxdata/telegraf/testutil"
+	"github.com/stretchr/testify/require"
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/internal"
-	"github.com/stretchr/testify/require"
+	"github.com/influxdata/telegraf/testutil"
 )
 
 func getMetric() telegraf.Metric {
@@ -87,7 +87,7 @@ func TestStatusCode(t *testing.T) {
 			plugin: &Loki{
 				Domain: u.String(),
 			},
-			statusCode: 103,
+			statusCode: http.StatusSwitchingProtocols,
 			errFunc: func(t *testing.T, err error) {
 				require.Error(t, err)
 			},
@@ -225,7 +225,7 @@ func TestContentEncodingGzip(t *testing.T) {
 				require.Len(t, s.Streams, 1)
 				require.Len(t, s.Streams[0].Logs, 1)
 				require.Len(t, s.Streams[0].Logs[0], 2)
-				require.Equal(t, map[string]string{"key1": "value1"}, s.Streams[0].Labels)
+				require.Equal(t, map[string]string{"__name": "log", "key1": "value1"}, s.Streams[0].Labels)
 				require.Equal(t, "123000000000", s.Streams[0].Logs[0][0])
 				require.Contains(t, s.Streams[0].Logs[0][1], "line=\"my log\"")
 				require.Contains(t, s.Streams[0].Logs[0][1], "field=\"3.14\"")
@@ -329,7 +329,8 @@ func TestOAuthClientCredentialsGrant(t *testing.T) {
 				values.Add("access_token", token)
 				values.Add("token_type", "bearer")
 				values.Add("expires_in", "3600")
-				w.Write([]byte(values.Encode()))
+				_, err = w.Write([]byte(values.Encode()))
+				require.NoError(t, err)
 			},
 			handler: func(t *testing.T, w http.ResponseWriter, r *http.Request) {
 				require.Equal(t, []string{"Bearer " + token}, r.Header["Authorization"])
@@ -404,7 +405,7 @@ func TestMetricSorting(t *testing.T) {
 			require.Len(t, s.Streams, 1)
 			require.Len(t, s.Streams[0].Logs, 2)
 			require.Len(t, s.Streams[0].Logs[0], 2)
-			require.Equal(t, map[string]string{"key1": "value1"}, s.Streams[0].Labels)
+			require.Equal(t, map[string]string{"__name": "log", "key1": "value1"}, s.Streams[0].Labels)
 			require.Equal(t, "456000000000", s.Streams[0].Logs[0][0])
 			require.Contains(t, s.Streams[0].Logs[0][1], "line=\"older log\"")
 			require.Contains(t, s.Streams[0].Logs[0][1], "field=\"3.14\"")
