@@ -1,9 +1,10 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package socket_writer
 
 import (
 	"crypto/tls"
+	_ "embed"
 	"fmt"
-	"log"
 	"net"
 	"strings"
 	"time"
@@ -16,11 +17,16 @@ import (
 	"github.com/influxdata/telegraf/plugins/serializers"
 )
 
+// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
+//go:embed sample.conf
+var sampleConfig string
+
 type SocketWriter struct {
 	ContentEncoding string `toml:"content_encoding"`
 	Address         string
 	KeepAlivePeriod *config.Duration
 	tlsint.ClientConfig
+	Log telegraf.Logger `toml:"-"`
 
 	serializers.Serializer
 
@@ -29,48 +35,8 @@ type SocketWriter struct {
 	net.Conn
 }
 
-func (sw *SocketWriter) Description() string {
-	return "Generic socket writer capable of handling multiple socket types."
-}
-
-func (sw *SocketWriter) SampleConfig() string {
-	return `
-  ## URL to connect to
-  # address = "tcp://127.0.0.1:8094"
-  # address = "tcp://example.com:http"
-  # address = "tcp4://127.0.0.1:8094"
-  # address = "tcp6://127.0.0.1:8094"
-  # address = "tcp6://[2001:db8::1]:8094"
-  # address = "udp://127.0.0.1:8094"
-  # address = "udp4://127.0.0.1:8094"
-  # address = "udp6://127.0.0.1:8094"
-  # address = "unix:///tmp/telegraf.sock"
-  # address = "unixgram:///tmp/telegraf.sock"
-
-  ## Optional TLS Config
-  # tls_ca = "/etc/telegraf/ca.pem"
-  # tls_cert = "/etc/telegraf/cert.pem"
-  # tls_key = "/etc/telegraf/key.pem"
-  ## Use TLS but skip chain & host verification
-  # insecure_skip_verify = false
-
-  ## Period between keep alive probes.
-  ## Only applies to TCP sockets.
-  ## 0 disables keep alive probes.
-  ## Defaults to the OS configuration.
-  # keep_alive_period = "5m"
-
-  ## Content encoding for packet-based connections (i.e. UDP, unixgram).
-  ## Can be set to "gzip" or to "identity" to apply no encoding.
-  ##
-  # content_encoding = "identity"
-
-  ## Data format to generate.
-  ## Each data format has its own unique set of configuration options, read
-  ## more about them here:
-  ## https://github.com/influxdata/telegraf/blob/master/docs/DATA_FORMATS_INPUT.md
-  # data_format = "influx"
-`
+func (*SocketWriter) SampleConfig() string {
+	return sampleConfig
 }
 
 func (sw *SocketWriter) SetSerializer(s serializers.Serializer) {
@@ -99,7 +65,7 @@ func (sw *SocketWriter) Connect() error {
 	}
 
 	if err := sw.setKeepAlive(c); err != nil {
-		log.Printf("unable to configure keep alive (%s): %s", sw.Address, err)
+		sw.Log.Debugf("Unable to configure keep alive (%s): %s", sw.Address, err)
 	}
 	//set encoder
 	sw.encoder, err = internal.NewContentEncoder(sw.ContentEncoding)
@@ -142,13 +108,13 @@ func (sw *SocketWriter) Write(metrics []telegraf.Metric) error {
 	for _, m := range metrics {
 		bs, err := sw.Serialize(m)
 		if err != nil {
-			log.Printf("D! [outputs.socket_writer] Could not serialize metric: %v", err)
+			sw.Log.Debugf("Could not serialize metric: %v", err)
 			continue
 		}
 
 		bs, err = sw.encoder.Encode(bs)
 		if err != nil {
-			log.Printf("D! [outputs.socket_writer] Could not encode metric: %v", err)
+			sw.Log.Debugf("Could not encode metric: %v", err)
 			continue
 		}
 
@@ -156,7 +122,7 @@ func (sw *SocketWriter) Write(metrics []telegraf.Metric) error {
 			//TODO log & keep going with remaining strings
 			if err, ok := err.(net.Error); !ok || !err.Temporary() {
 				// permanent error. close the connection
-				sw.Close()
+				sw.Close() //nolint:revive // There is another error which will be returned here
 				sw.Conn = nil
 				return fmt.Errorf("closing connection: %v", err)
 			}
