@@ -1,10 +1,11 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package warp10
 
 import (
 	"bytes"
+	_ "embed"
 	"fmt"
 	"io"
-	"log"
 	"math"
 	"net/http"
 	"net/url"
@@ -19,6 +20,10 @@ import (
 	"github.com/influxdata/telegraf/plugins/outputs"
 )
 
+// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
+//go:embed sample.conf
+var sampleConfig string
+
 const (
 	defaultClientTimeout = 15 * time.Second
 )
@@ -33,35 +38,9 @@ type Warp10 struct {
 	MaxStringErrorSize int             `toml:"max_string_error_size"`
 	client             *http.Client
 	tls.ClientConfig
+	Log telegraf.Logger `toml:"-"`
 }
 
-var sampleConfig = `
-  # Prefix to add to the measurement.
-  prefix = "telegraf."
-
-  # URL of the Warp 10 server
-  warp_url = "http://localhost:8080"
-
-  # Write token to access your app on warp 10
-  token = "Token"
-
-  # Warp 10 query timeout
-  # timeout = "15s"
-
-  ## Print Warp 10 error body
-  # print_error_body = false
-
-  ## Max string error size
-  # max_string_error_size = 511
-
-  ## Optional TLS Config
-  # tls_ca = "/etc/telegraf/ca.pem"
-  # tls_cert = "/etc/telegraf/cert.pem"
-  # tls_key = "/etc/telegraf/key.pem"
-  ## Use TLS but skip chain & host verification
-  # insecure_skip_verify = false
-`
-
 // MetricLine Warp 10 metrics
 type MetricLine struct {
 	Metric    string
@@ -91,6 +70,10 @@ func (w *Warp10) createClient() (*http.Client, error) {
 	return client, nil
 }
 
+func (*Warp10) SampleConfig() string {
+	return sampleConfig
+}
+
 // Connect to warp10
 func (w *Warp10) Connect() error {
 	client, err := w.createClient()
@@ -114,7 +97,7 @@ func (w *Warp10) GenWarp10Payload(metrics []telegraf.Metric) string {
 
 			metricValue, err := buildValue(field.Value)
 			if err != nil {
-				log.Printf("E! [outputs.warp10] Could not encode value: %v", err)
+				w.Log.Errorf("Could not encode value: %v", err)
 				continue
 			}
 			metric.Value = metricValue
@@ -189,7 +172,7 @@ func buildValue(v interface{}) (string, error) {
 	case int64:
 		retv = intToString(p)
 	case string:
-		retv = fmt.Sprintf("'%s'", strings.Replace(p, "'", "\\'", -1))
+		retv = fmt.Sprintf("'%s'", strings.ReplaceAll(p, "'", "\\'"))
 	case bool:
 		retv = boolToString(p)
 	case uint64:
@@ -199,7 +182,7 @@ func buildValue(v interface{}) (string, error) {
 			retv = strconv.FormatInt(math.MaxInt64, 10)
 		}
 	case float64:
-		retv = floatToString(float64(p))
+		retv = floatToString(p)
 	default:
 		return "", fmt.Errorf("unsupported type: %T", v)
 	}
@@ -218,16 +201,6 @@ func floatToString(inputNum float64) string {
 	return strconv.FormatFloat(inputNum, 'f', 6, 64)
 }
 
-// SampleConfig get config
-func (w *Warp10) SampleConfig() string {
-	return sampleConfig
-}
-
-// Description get description
-func (w *Warp10) Description() string {
-	return "Write metrics to Warp 10"
-}
-
 // Close close
 func (w *Warp10) Close() error {
 	return nil
